@@ -16,8 +16,7 @@ class ApplicationUserServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count(async_req=True)
         >>> result = thread.get()
 
@@ -28,8 +27,8 @@ class ApplicationUserServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.count_with_http_info(**kwargs)
         else:
@@ -41,8 +40,7 @@ class ApplicationUserServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count_with_http_info(async_req=True)
         >>> result = thread.get()
 
@@ -57,7 +55,7 @@ class ApplicationUserServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -107,7 +105,7 @@ class ApplicationUserServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def create(self, entity, **kwargs):
@@ -115,8 +113,7 @@ class ApplicationUserServiceApi:
 
         Creates the application user with the given properties.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.create(entity, async_req=True)
         >>> result = thread.get()
 
@@ -127,8 +124,8 @@ class ApplicationUserServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.create_with_http_info(entity, **kwargs)
         else:
@@ -140,8 +137,7 @@ class ApplicationUserServiceApi:
 
         Creates the application user with the given properties.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.create_with_http_info(entity, async_req=True)
         >>> result = thread.get()
 
@@ -156,7 +152,7 @@ class ApplicationUserServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -210,7 +206,7 @@ class ApplicationUserServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def delete(self, id, **kwargs):
@@ -218,8 +214,7 @@ class ApplicationUserServiceApi:
 
         Deletes the entity with the given id.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.delete(id, async_req=True)
         >>> result = thread.get()
 
@@ -230,8 +225,8 @@ class ApplicationUserServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.delete_with_http_info(id, **kwargs)
         else:
@@ -243,8 +238,7 @@ class ApplicationUserServiceApi:
 
         Deletes the entity with the given id.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.delete_with_http_info(id, async_req=True)
         >>> result = thread.get()
 
@@ -259,7 +253,7 @@ class ApplicationUserServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -313,7 +307,7 @@ class ApplicationUserServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def read(self, id, **kwargs):
@@ -321,8 +315,7 @@ class ApplicationUserServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read(id, async_req=True)
         >>> result = thread.get()
 
@@ -333,8 +326,8 @@ class ApplicationUserServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.read_with_http_info(id, **kwargs)
         else:
@@ -346,8 +339,7 @@ class ApplicationUserServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read_with_http_info(id, async_req=True)
         >>> result = thread.get()
 
@@ -362,7 +354,7 @@ class ApplicationUserServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -416,7 +408,7 @@ class ApplicationUserServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def search(self, query, **kwargs):
@@ -424,8 +416,7 @@ class ApplicationUserServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search(query, async_req=True)
         >>> result = thread.get()
 
@@ -436,8 +427,8 @@ class ApplicationUserServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.search_with_http_info(query, **kwargs)
         else:
@@ -449,8 +440,7 @@ class ApplicationUserServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search_with_http_info(query, async_req=True)
         >>> result = thread.get()
 
@@ -465,7 +455,7 @@ class ApplicationUserServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -519,7 +509,7 @@ class ApplicationUserServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def update(self, entity, **kwargs):
@@ -527,8 +517,7 @@ class ApplicationUserServiceApi:
 
         This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.update(entity, async_req=True)
         >>> result = thread.get()
 
@@ -539,8 +528,8 @@ class ApplicationUserServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.update_with_http_info(entity, **kwargs)
         else:
@@ -552,8 +541,7 @@ class ApplicationUserServiceApi:
 
         This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.update_with_http_info(entity, async_req=True)
         >>> result = thread.get()
 
@@ -568,7 +556,7 @@ class ApplicationUserServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -622,5 +610,5 @@ class ApplicationUserServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
