@@ -16,8 +16,7 @@ class InstallmentPaymentServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count(space_id, filter, async_req=True)
         >>> result = thread.get()
 
@@ -29,8 +28,8 @@ class InstallmentPaymentServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.count_with_http_info(space_id, filter, **kwargs)
         else:
@@ -42,8 +41,7 @@ class InstallmentPaymentServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count_with_http_info(space_id, filter, async_req=True)
         >>> result = thread.get()
 
@@ -59,7 +57,7 @@ class InstallmentPaymentServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -119,7 +117,7 @@ class InstallmentPaymentServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def create_installment_payment(self, space_id, transaction_id, installment_plan_configuration, **kwargs):
@@ -127,8 +125,7 @@ class InstallmentPaymentServiceApi:
 
         This operation creates based up on the given transaction an installment payment.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.create_installment_payment(space_id, transaction_id, installment_plan_configuration, async_req=True)
         >>> result = thread.get()
 
@@ -141,8 +138,8 @@ class InstallmentPaymentServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.create_installment_payment_with_http_info(space_id, transaction_id, installment_plan_configuration, **kwargs)
         else:
@@ -154,8 +151,7 @@ class InstallmentPaymentServiceApi:
 
         This operation creates based up on the given transaction an installment payment.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.create_installment_payment_with_http_info(space_id, transaction_id, installment_plan_configuration, async_req=True)
         >>> result = thread.get()
 
@@ -172,7 +168,7 @@ class InstallmentPaymentServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -234,7 +230,7 @@ class InstallmentPaymentServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def read(self, space_id, id, **kwargs):
@@ -242,8 +238,7 @@ class InstallmentPaymentServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read(space_id, id, async_req=True)
         >>> result = thread.get()
 
@@ -255,8 +250,8 @@ class InstallmentPaymentServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.read_with_http_info(space_id, id, **kwargs)
         else:
@@ -268,8 +263,7 @@ class InstallmentPaymentServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read_with_http_info(space_id, id, async_req=True)
         >>> result = thread.get()
 
@@ -285,7 +279,7 @@ class InstallmentPaymentServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -345,7 +339,7 @@ class InstallmentPaymentServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def search(self, space_id, query, **kwargs):
@@ -353,8 +347,7 @@ class InstallmentPaymentServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -366,8 +359,8 @@ class InstallmentPaymentServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.search_with_http_info(space_id, query, **kwargs)
         else:
@@ -379,8 +372,7 @@ class InstallmentPaymentServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search_with_http_info(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -396,7 +388,7 @@ class InstallmentPaymentServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -456,5 +448,5 @@ class InstallmentPaymentServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
