@@ -16,8 +16,7 @@ class PaymentTerminalServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count(space_id, async_req=True)
         >>> result = thread.get()
 
@@ -29,8 +28,8 @@ class PaymentTerminalServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.count_with_http_info(space_id, **kwargs)
         else:
@@ -42,8 +41,7 @@ class PaymentTerminalServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count_with_http_info(space_id, async_req=True)
         >>> result = thread.get()
 
@@ -59,7 +57,7 @@ class PaymentTerminalServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -115,7 +113,7 @@ class PaymentTerminalServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def link(self, space_id, terminal_id, serial_number, **kwargs):
@@ -123,8 +121,7 @@ class PaymentTerminalServiceApi:
 
         Links the device with given serial number with terminal.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.link(space_id, terminal_id, serial_number, async_req=True)
         >>> result = thread.get()
 
@@ -137,8 +134,8 @@ class PaymentTerminalServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.link_with_http_info(space_id, terminal_id, serial_number, **kwargs)
         else:
@@ -150,8 +147,7 @@ class PaymentTerminalServiceApi:
 
         Links the device with given serial number with terminal.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.link_with_http_info(space_id, terminal_id, serial_number, async_req=True)
         >>> result = thread.get()
 
@@ -168,7 +164,7 @@ class PaymentTerminalServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -226,7 +222,7 @@ class PaymentTerminalServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def read(self, space_id, id, **kwargs):
@@ -234,8 +230,7 @@ class PaymentTerminalServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read(space_id, id, async_req=True)
         >>> result = thread.get()
 
@@ -247,8 +242,8 @@ class PaymentTerminalServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.read_with_http_info(space_id, id, **kwargs)
         else:
@@ -260,8 +255,7 @@ class PaymentTerminalServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read_with_http_info(space_id, id, async_req=True)
         >>> result = thread.get()
 
@@ -277,7 +271,7 @@ class PaymentTerminalServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -337,7 +331,7 @@ class PaymentTerminalServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def search(self, space_id, query, **kwargs):
@@ -345,8 +339,7 @@ class PaymentTerminalServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -358,8 +351,8 @@ class PaymentTerminalServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.search_with_http_info(space_id, query, **kwargs)
         else:
@@ -371,8 +364,7 @@ class PaymentTerminalServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search_with_http_info(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -388,7 +380,7 @@ class PaymentTerminalServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -448,213 +440,7 @@ class PaymentTerminalServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
-            collection_formats=collection_formats)
-
-    def trigger_final_balance(self, space_id, terminal_id, **kwargs):
-        """Remotely Trigger Final Balance
-
-        Remotely triggers the final balance receipt on the terminal.
-        This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
-        >>> thread = api.trigger_final_balance(space_id, terminal_id, async_req=True)
-        >>> result = thread.get()
-
-        :param async_req bool
-        :param int space_id:  (required)
-        :param int terminal_id:  (required)
-        :return: None
-                 If the method is called asynchronously,
-                 returns the request thread.
-        """
-        kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
-        if kwargs.get('async_req'):
-            return self.trigger_final_balance_with_http_info(space_id, terminal_id, **kwargs)
-        else:
-            (data) = self.trigger_final_balance_with_http_info(space_id, terminal_id, **kwargs)
-            return data
-
-    def trigger_final_balance_with_http_info(self, space_id, terminal_id, **kwargs):
-        """Remotely Trigger Final Balance
-
-        Remotely triggers the final balance receipt on the terminal.
-        This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
-        >>> thread = api.trigger_final_balance_with_http_info(space_id, terminal_id, async_req=True)
-        >>> result = thread.get()
-
-        :param async_req bool
-        :param int space_id:  (required)
-        :param int terminal_id:  (required)
-        :return: None
-                 If the method is called asynchronously,
-                 returns the request thread.
-        """
-
-        all_params = ['space_id', 'terminal_id']
-        all_params.append('async_req')
-        all_params.append('_return_http_data_only')
-        all_params.append('_preload_content')
-        all_params.append('request_timeout')
-
-        params = locals()
-        for key, val in six.iteritems(params['kwargs']):
-            if key not in all_params:
-                raise TypeError(
-                    "Got an unexpected keyword argument '%s'"
-                    " to method trigger_final_balance" % key
-                )
-            params[key] = val
-        del params['kwargs']
-        # verify the required parameter 'space_id' is set
-        if ('space_id' not in params or
-                params['space_id'] is None):
-            raise ValueError("Missing the required parameter `space_id` when calling `trigger_final_balance`")
-        # verify the required parameter 'terminal_id' is set
-        if ('terminal_id' not in params or
-                params['terminal_id'] is None):
-            raise ValueError("Missing the required parameter `terminal_id` when calling `trigger_final_balance`")
-
-        collection_formats = {}
-
-        path_params = {}
-
-        query_params = []
-        if 'space_id' in params:
-            query_params.append(('spaceId', params['space_id']))
-        if 'terminal_id' in params:
-            query_params.append(('terminalId', params['terminal_id']))
-
-        header_params = {}
-
-        form_params = []
-        local_var_files = {}
-
-        body_params = None
-        # Authentication setting
-        auth_settings = []
-
-        return self.api_client.call_api(
-            '/payment-terminal/trigger-final-balance', 'POST',
-            path_params,
-            query_params,
-            header_params,
-            body=body_params,
-            post_params=form_params,
-            files=local_var_files,
-            response_type=None,
-            auth_settings=auth_settings,
-            async_req=params.get('async_req'),
-            _return_http_data_only=params.get('_return_http_data_only'),
-            _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
-            collection_formats=collection_formats)
-
-    def trigger_final_balance_by_identifier(self, space_id, terminal_identifier, **kwargs):
-        """Remotely Trigger Final Balance By Identifier
-
-        Remotely triggers the final balance receipt on the terminal by terminal identifier.
-        This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
-        >>> thread = api.trigger_final_balance_by_identifier(space_id, terminal_identifier, async_req=True)
-        >>> result = thread.get()
-
-        :param async_req bool
-        :param int space_id:  (required)
-        :param str terminal_identifier:  (required)
-        :return: None
-                 If the method is called asynchronously,
-                 returns the request thread.
-        """
-        kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
-        if kwargs.get('async_req'):
-            return self.trigger_final_balance_by_identifier_with_http_info(space_id, terminal_identifier, **kwargs)
-        else:
-            (data) = self.trigger_final_balance_by_identifier_with_http_info(space_id, terminal_identifier, **kwargs)
-            return data
-
-    def trigger_final_balance_by_identifier_with_http_info(self, space_id, terminal_identifier, **kwargs):
-        """Remotely Trigger Final Balance By Identifier
-
-        Remotely triggers the final balance receipt on the terminal by terminal identifier.
-        This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
-        >>> thread = api.trigger_final_balance_by_identifier_with_http_info(space_id, terminal_identifier, async_req=True)
-        >>> result = thread.get()
-
-        :param async_req bool
-        :param int space_id:  (required)
-        :param str terminal_identifier:  (required)
-        :return: None
-                 If the method is called asynchronously,
-                 returns the request thread.
-        """
-
-        all_params = ['space_id', 'terminal_identifier']
-        all_params.append('async_req')
-        all_params.append('_return_http_data_only')
-        all_params.append('_preload_content')
-        all_params.append('request_timeout')
-
-        params = locals()
-        for key, val in six.iteritems(params['kwargs']):
-            if key not in all_params:
-                raise TypeError(
-                    "Got an unexpected keyword argument '%s'"
-                    " to method trigger_final_balance_by_identifier" % key
-                )
-            params[key] = val
-        del params['kwargs']
-        # verify the required parameter 'space_id' is set
-        if ('space_id' not in params or
-                params['space_id'] is None):
-            raise ValueError("Missing the required parameter `space_id` when calling `trigger_final_balance_by_identifier`")
-        # verify the required parameter 'terminal_identifier' is set
-        if ('terminal_identifier' not in params or
-                params['terminal_identifier'] is None):
-            raise ValueError("Missing the required parameter `terminal_identifier` when calling `trigger_final_balance_by_identifier`")
-
-        collection_formats = {}
-
-        path_params = {}
-
-        query_params = []
-        if 'space_id' in params:
-            query_params.append(('spaceId', params['space_id']))
-        if 'terminal_identifier' in params:
-            query_params.append(('terminalIdentifier', params['terminal_identifier']))
-
-        header_params = {}
-
-        form_params = []
-        local_var_files = {}
-
-        body_params = None
-        # Authentication setting
-        auth_settings = []
-
-        return self.api_client.call_api(
-            '/payment-terminal/trigger-final-balance-by-identifier', 'POST',
-            path_params,
-            query_params,
-            header_params,
-            body=body_params,
-            post_params=form_params,
-            files=local_var_files,
-            response_type=None,
-            auth_settings=auth_settings,
-            async_req=params.get('async_req'),
-            _return_http_data_only=params.get('_return_http_data_only'),
-            _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def unlink(self, space_id, terminal_id, **kwargs):
@@ -662,8 +448,7 @@ class PaymentTerminalServiceApi:
 
         Unlinks the device from terminal.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.unlink(space_id, terminal_id, async_req=True)
         >>> result = thread.get()
 
@@ -675,8 +460,8 @@ class PaymentTerminalServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.unlink_with_http_info(space_id, terminal_id, **kwargs)
         else:
@@ -688,8 +473,7 @@ class PaymentTerminalServiceApi:
 
         Unlinks the device from terminal.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.unlink_with_http_info(space_id, terminal_id, async_req=True)
         >>> result = thread.get()
 
@@ -705,7 +489,7 @@ class PaymentTerminalServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -757,5 +541,5 @@ class PaymentTerminalServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
