@@ -16,8 +16,7 @@ class ShopifySubscriberServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count(space_id, async_req=True)
         >>> result = thread.get()
 
@@ -29,8 +28,8 @@ class ShopifySubscriberServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.count_with_http_info(space_id, **kwargs)
         else:
@@ -42,8 +41,7 @@ class ShopifySubscriberServiceApi:
 
         Counts the number of items in the database as restricted by the given filter.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.count_with_http_info(space_id, async_req=True)
         >>> result = thread.get()
 
@@ -59,7 +57,7 @@ class ShopifySubscriberServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -115,7 +113,7 @@ class ShopifySubscriberServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def read(self, space_id, id, **kwargs):
@@ -123,8 +121,7 @@ class ShopifySubscriberServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read(space_id, id, async_req=True)
         >>> result = thread.get()
 
@@ -136,8 +133,8 @@ class ShopifySubscriberServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.read_with_http_info(space_id, id, **kwargs)
         else:
@@ -149,8 +146,7 @@ class ShopifySubscriberServiceApi:
 
         Reads the entity with the given 'id' and returns it.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.read_with_http_info(space_id, id, async_req=True)
         >>> result = thread.get()
 
@@ -166,7 +162,7 @@ class ShopifySubscriberServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -226,7 +222,7 @@ class ShopifySubscriberServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def search(self, space_id, query, **kwargs):
@@ -234,8 +230,7 @@ class ShopifySubscriberServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -247,8 +242,8 @@ class ShopifySubscriberServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.search_with_http_info(space_id, query, **kwargs)
         else:
@@ -260,8 +255,7 @@ class ShopifySubscriberServiceApi:
 
         Searches for the entities as specified by the given query.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.search_with_http_info(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -277,7 +271,7 @@ class ShopifySubscriberServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -337,7 +331,7 @@ class ShopifySubscriberServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
 
     def update(self, space_id, query, **kwargs):
@@ -345,8 +339,7 @@ class ShopifySubscriberServiceApi:
 
         This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.update(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -358,8 +351,8 @@ class ShopifySubscriberServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-        
-        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
+
+
         if kwargs.get('async_req'):
             return self.update_with_http_info(space_id, query, **kwargs)
         else:
@@ -371,8 +364,7 @@ class ShopifySubscriberServiceApi:
 
         This updates the entity with the given properties. Only those properties which should be updated can be provided. The 'id' and 'version' are required to identify the entity.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True.
-        
+        asynchronous HTTP request, please pass async_req=True
         >>> thread = api.update_with_http_info(space_id, query, async_req=True)
         >>> result = thread.get()
 
@@ -388,7 +380,7 @@ class ShopifySubscriberServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('request_timeout')
+        all_params.append('_request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -448,5 +440,5 @@ class ShopifySubscriberServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('request_timeout'),
+            _request_timeout=params.get('_request_timeout'),
             collection_formats=collection_formats)
